// Copyright 2018 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.google.devtools.build.lib.buildtool.buildevent;

import com.google.devtools.build.lib.events.ExtendedEventHandler;
import com.google.devtools.build.lib.runtime.InstrumentationOutput;
import javax.annotation.Nullable;

/** This event is fired when the profiler is started. */
public final class ProfilerStartedEvent implements ExtendedEventHandler.Postable {
  @Nullable private final InstrumentationOutput profile;

  public ProfilerStartedEvent(@Nullable InstrumentationOutput profile) {
    this.profile = profile;
  }

  @Nullable
  public InstrumentationOutput getProfile() {
    return profile;
  }
}
