// Copyright 2021 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.devtools.build.lib.skyframe.serialization;

/**
 * Common interface for {@link SerializationContext} and {@link DeserializationContext}, which both
 * provide access to dependencies required for serialization.
 */
public interface SerializationDependencyProvider {

  /**
   * Returns the dependency associated with the given type.
   *
   * @throws NullPointerException if there is no dependency registered for the given type
   */
  <T> T getDependency(Class<T> type);
}
